@@ -74,7 +74,7 @@ default_settings = {
             'create': {
                 'success_url': 'process-processes',
                 'success_message': _('process created successfully'),
-                'permissions': ['process.view_processes', 'process.add_processes'],
+                'permissions': ['process.view_processes', 'process.add_process'],
             },
             'list': {
                 'url_allow_filters': {'id': []},
@@ -83,12 +83,12 @@ default_settings = {
             'update': {
                 'success_url': 'process-processes',
                 'success_message': _('process updated successfully'),
-                'permissions': ['process.view_processes', 'process.change_processes'],
+                'permissions': ['process.view_processes', 'process.change_process'],
             },
             'delete': {
                 'success_url': 'process-processes',
                 'success_message': _('process deleted successfully'),
-                'permissions': ['process.view_processes', 'process.delete_processes'],
+                'permissions': ['process.view_processes', 'process.delete_process'],
             },
         },
         'task': {
